==> tour-2.0.0.tar.gz: tour/src/Controller/TourUIController.php <==
<?php

namespace Drupal\tour\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Tour UI Controller.
 */
class TourUIController extends ControllerBase {

  /**
   * Constructs a new TourUIController object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   */
  public function __construct(protected Connection $database) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('database')
    );
  }

  /**
   * Returns list of modules included as part of the URL string.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The Request Service.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Return list in JSON format.
   */
  public function getModules(Request $request): JsonResponse {
    $matches = [];

    $part = $request->query->get('q');
    if ($part) {
      $matches[] = $part;

      // Escape user input.
      $part = preg_quote($part);

      $modules = $this->moduleHandler->getModuleList();
      foreach ($modules as $module => $data) {
        if (preg_match("/$part/", $module)) {
          $matches[] = $module;
        }
      }
    }

    return new JsonResponse($matches);
  }

  /**
   * Build list of route and path pattern.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The Request Service.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Return list in JSON format.
   */
  public function getRoutes(Request $request): JsonResponse {
    $matches = [];

    $part = $request->query->get('q');
    if ($part && strlen($part) > 3) {
      $list = [];
      $result = $this->database->query('SELECT * from {router}');
      foreach ($result as $row) {
        $list[$row->name] = $row->name . ' (' . $row->pattern_outline . ')';
      }
      asort($list);

      $matches[] = $part;
      $part = preg_quote($part, '/');
      foreach ($list as $data) {
        if (preg_match("/$part/", $data)) {
          $matches[] = $data;
        }
      }
    }

    return new JsonResponse($matches);
  }

  /**
   * Enable Tour via UI.
   *
   * @param string $tour_id
   *   Tour ID to enable.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  public function enable(string $tour_id): RedirectResponse {
    return $this->setStatus($tour_id, TRUE);
  }

  /**
   * Disable Tour via UI.
   *
   * @param string $tour_id
   *   Tour ID to disable.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  public function disable(string $tour_id): RedirectResponse {
    return $this->setStatus($tour_id, FALSE);
  }

  /**
   * Set status of given tour.
   *
   * @param string $tour
   *   Tour ID to set status for.
   * @param bool $status
   *   Value to set tour to.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect response.
   */
  protected function setStatus(string $tour, bool $status): RedirectResponse {
    $entity = $this->entityTypeManager()
      ->getStorage('tour')
      ->load($tour);
    $entity->set('status', $status);
    $entity->save();

    return new RedirectResponse('/admin/config/user-interface/tour');
  }

}

==> tour-2.0.3.tar.gz: tour/src/Controller/TourUIController.php <==
<?php

namespace Drupal\tour\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Tour UI Controller.
 */
class TourUIController extends ControllerBase {

  /**
   * Constructs a new TourUIController object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   */
  public function __construct(protected Connection $database) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('database')
    );
  }

  /**
   * Returns list of modules included as part of the URL string.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The Request Service.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Return list in JSON format.
   */
  public function getModules(Request $request): JsonResponse {
    $matches = [];

    $part = $request->query->get('q');
    if ($part) {
      $matches[] = $part;

      // Escape user input.
      $part = preg_quote($part);

      $modules = $this->moduleHandler()->getModuleList();
      foreach ($modules as $module => $data) {
        if (preg_match("/$part/", $module)) {
          $matches[] = $module;
        }
      }
    }

    return new JsonResponse($matches);
  }

  /**
   * Build list of route and path pattern.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The Request Service.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Return list in JSON format.
   */
  public function getRoutes(Request $request): JsonResponse {
    $matches = [];

    $part = $request->query->get('q');
    if ($part && strlen($part) > 3) {
      $list = [];
      $result = $this->database->query('SELECT * from {router}');
      foreach ($result as $row) {
        $list[$row->name] = $row->name . ' (' . $row->pattern_outline . ')';
      }
      asort($list);

      $matches[] = $part;
      $part = preg_quote($part, '/');
      foreach ($list as $data) {
        if (preg_match("/$part/", $data)) {
          $matches[] = $data;
        }
      }
    }

    return new JsonResponse($matches);
  }

  /**
   * Enable Tour via UI.
   *
   * @param string $tour_id
   *   Tour ID to enable.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  public function enable(string $tour_id): RedirectResponse {
    return $this->setStatus($tour_id, TRUE);
  }

  /**
   * Disable Tour via UI.
   *
   * @param string $tour_id
   *   Tour ID to disable.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  public function disable(string $tour_id): RedirectResponse {
    return $this->setStatus($tour_id, FALSE);
  }

  /**
   * Set status of given tour.
   *
   * @param string $tour
   *   Tour ID to set status for.
   * @param bool $status
   *   Value to set tour to.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect response.
   */
  protected function setStatus(string $tour, bool $status): RedirectResponse {
    $entity = $this->entityTypeManager()
      ->getStorage('tour')
      ->load($tour);
    $entity->set('status', $status);
    $entity->save();

    return new RedirectResponse('/admin/config/user-interface/tour');
  }

}
